@@ -36,9 +36,9 @@
 #include "HTMLVideoElement.h"
 #include "JSHTMLAudioElement.h"
 #include "JSHTMLVideoElement.h"
-#include <QDebug>
+#include "khtml_debug.h"
 #include <khtml_part.h>
-#include <QtCore/QList>
+#include <QList>
 
 #include "kjs_html.h"
 #include "kjs_css.h"
@@ -125,7 +125,7 @@ KJS_IMPLEMENT_PROTOTYPE_IMP("DOMNode", DOMNodeProto, DOMNodeProtoFunc, DOMNodeCo
     putDirect(exec->propertyNames().constructor, NodeConstructor::self(exec), DontEnum);
 }
 
-const ClassInfo DOMNode::info = { "Node", 0, &DOMNodeTable, 0 };
+const ClassInfo DOMNode::info = { "Node", nullptr, &DOMNodeTable, nullptr };
 
 DOMNode::DOMNode(ExecState *exec, DOM::NodeImpl *n)
     : DOMObject(DOMNodeProto::self(exec)), m_impl(n)
@@ -215,7 +215,7 @@ bool DOMNode::toBoolean(ExecState *) const
 bool DOMNode::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMNode::getOwnPropertySlot " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMNode::getOwnPropertySlot " << propertyName.qstring();
 #endif
     return getStaticValueSlot<DOMNode, DOMObject>(exec, &DOMNodeTable, this, propertyName, slot);
 }
@@ -225,7 +225,7 @@ static khtml::RenderObject *handleBodyRootQuirk(const DOM::NodeImpl *node, khtml
     //This emulates the quirks of various height/width properties on the viewport and root. Note that it
     //is (mostly) IE-compatible in quirks, and mozilla-compatible in strict.
     if (!rend) {
-        return 0;
+        return nullptr;
     }
 
     bool quirksMode = rend->style() && rend->style()->htmlHacks();
@@ -293,7 +293,7 @@ JSValue *DOMNode::getValueProperty(ExecState *exec, int token) const
     case NextSibling:
         return getDOMNode(exec, node.nextSibling());
     case Attributes: {
-        DOM::NamedNodeMapImpl *attrs = 0;
+        DOM::NamedNodeMapImpl *attrs = nullptr;
         if (node.isElementNode()) {
             DOM::ElementImpl &el = static_cast<DOM::ElementImpl &>(node);
             attrs = el.attributes();
@@ -399,8 +399,8 @@ JSValue *DOMNode::getValueProperty(ExecState *exec, int token) const
         case OffsetHeight:
             return rend ? jsNumber(rend->offsetHeight()) : jsNumber(0);
         case OffsetParent: {
-            khtml::RenderObject *par = rend ? rend->offsetParent() : 0;
-            return getDOMNode(exec, par ? par->element() : 0);
+            khtml::RenderObject *par = rend ? rend->offsetParent() : nullptr;
+            return getDOMNode(exec, par ? par->element() : nullptr);
         }
         case ClientWidth:
             return rend ? jsNumber(rend->clientWidth()) : jsNumber(0);
@@ -431,7 +431,7 @@ JSValue *DOMNode::getValueProperty(ExecState *exec, int token) const
             }
             return jsNumber(0);
         default:
-            // qDebug() << "WARNING: Unhandled token in DOMNode::getValueProperty : " << token;
+            // qCDebug(KHTML_LOG) << "WARNING: Unhandled token in DOMNode::getValueProperty : " << token;
             break;
         }
     }
@@ -441,7 +441,7 @@ JSValue *DOMNode::getValueProperty(ExecState *exec, int token) const
 void DOMNode::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMNode::tryPut " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMNode::tryPut " << propertyName.qstring();
 #endif
     lookupPut<DOMNode, DOMObject>(exec, propertyName, value, attr,
                                   &DOMNodeTable, this);
@@ -572,7 +572,7 @@ void DOMNode::putValueProperty(ExecState *exec, int token, JSValue *value, int /
             }
             break;
         default:
-            // qDebug() << "WARNING: DOMNode::putValueProperty unhandled token " << token;
+            // qCDebug(KHTML_LOG) << "WARNING: DOMNode::putValueProperty unhandled token " << token;
             break;
         }
     }
@@ -739,7 +739,7 @@ KJS_IMPLEMENT_PROTOTYPE("DOMNodeList", DOMNodeListProto, DOMNodeListProtoFunc, O
 
 IMPLEMENT_PSEUDO_CONSTRUCTOR(NodeListPseudoCtor, "NodeList", DOMNodeListProto)
 
-const ClassInfo DOMNodeList::info = { "NodeList", 0, 0, 0 };
+const ClassInfo DOMNodeList::info = { "NodeList", nullptr, nullptr, nullptr };
 
 DOMNodeList::DOMNodeList(ExecState *exec, DOM::NodeListImpl *l)
     : DOMObject(DOMNodeListProto::self(exec)), m_impl(l) { }
@@ -780,7 +780,7 @@ DOM::NodeImpl *DOMNodeList::getByName(const Identifier &name)
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 bool DOMNodeList::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
@@ -868,7 +868,7 @@ JSValue *DOMNodeListProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj
 // -------------------------------------------------------------------------
 
 //### FIXME: link to the node prototype.
-const ClassInfo DOMAttr::info = { "Attr", &DOMNode::info, &DOMAttrTable, 0 };
+const ClassInfo DOMAttr::info = { "Attr", &DOMNode::info, &DOMAttrTable, nullptr };
 
 /* Source for DOMAttrTable.
 @begin DOMAttrTable 5
@@ -881,7 +881,7 @@ const ClassInfo DOMAttr::info = { "Attr", &DOMNode::info, &DOMAttrTable, 0 };
 bool DOMAttr::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMAttr::tryGet " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMAttr::tryGet " << propertyName.qstring();
 #endif
     return getStaticValueSlot<DOMAttr, DOMNode>(exec, &DOMAttrTable, this, propertyName, slot);
 }
@@ -905,7 +905,7 @@ JSValue *DOMAttr::getValueProperty(ExecState *exec, int token) const
 void DOMAttr::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMAttr::tryPut " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMAttr::tryPut " << propertyName.qstring();
 #endif
     lookupPut<DOMAttr, DOMNode>(exec, propertyName, value, attr,
                                 &DOMAttrTable, this);
@@ -919,14 +919,14 @@ void DOMAttr::putValueProperty(ExecState *exec, int token, JSValue *value, int /
         static_cast<AttrImpl *>(impl())->setValue(value->toString(exec).domString(), exception);
         return;
     default:
-        qWarning() << "DOMAttr::putValueProperty unhandled token " << token;
+        qCWarning(KHTML_LOG) << "DOMAttr::putValueProperty unhandled token " << token;
     }
 }
 
 AttrImpl *toAttr(JSValue *val)
 {
     if (!val || !val->isObject(&DOMAttr::info)) {
-        return 0;
+        return nullptr;
     }
     return static_cast<AttrImpl *>(static_cast<DOMNode *>(val)->impl());
 }
@@ -977,7 +977,7 @@ KJS_IMPLEMENT_PROTOTYPE("DOMDocument", DOMDocumentProto, DOMDocumentProtoFunc, D
 
 IMPLEMENT_PSEUDO_CONSTRUCTOR(DocumentPseudoCtor, "Document", DOMDocumentProto)
 
-const ClassInfo DOMDocument::info = { "Document", &DOMNode::info, &DOMDocumentTable, 0 };
+const ClassInfo DOMDocument::info = { "Document", &DOMNode::info, &DOMDocumentTable, nullptr };
 
 /* Source for DOMDocumentTable.
 @begin DOMDocumentTable 4
@@ -1008,7 +1008,7 @@ DOMDocument::DOMDocument(JSObject *proto, DOM::DocumentImpl *d)
 bool DOMDocument::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMDocument::tryGet " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMDocument::tryGet " << propertyName.qstring();
 #endif
     return getStaticValueSlot<DOMDocument, DOMNode>(
                exec, &DOMDocumentTable, this, propertyName, slot);
@@ -1033,7 +1033,7 @@ JSValue *DOMDocument::getValueProperty(ExecState *exec, int token) const
         }
     }
     case StyleSheets:
-        //qDebug() << "DOMDocument::StyleSheets, returning " << doc.styleSheets().length() << " stylesheets";
+        //qCDebug(KHTML_LOG) << "DOMDocument::StyleSheets, returning " << doc.styleSheets().length() << " stylesheets";
         return getDOMStyleSheetList(exec, doc.styleSheets(), &doc);
     case DOMDocument::DefaultView: { // DOM2
         KHTMLPart *part = doc.part();
@@ -1065,7 +1065,7 @@ JSValue *DOMDocument::getValueProperty(ExecState *exec, int token) const
     case Title:
         return jsString(doc.title());
     default:
-        // qDebug() << "WARNING: DOMDocument::getValueProperty unhandled token " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: DOMDocument::getValueProperty unhandled token " << token;
         return jsNull();
     }
 }
@@ -1073,7 +1073,7 @@ JSValue *DOMDocument::getValueProperty(ExecState *exec, int token) const
 void DOMDocument::put(ExecState *exec, const Identifier &propertyName, JSValue *value, int attr)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMDocument::tryPut " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMDocument::tryPut " << propertyName.qstring();
 #endif
     lookupPut<DOMDocument, DOMNode>(exec, propertyName, value, attr, &DOMDocumentTable, this);
 }
@@ -1112,7 +1112,7 @@ JSValue *DOMDocumentProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj
     // we can do it fast, without copying the data
     if (id == DOMDocument::GetElementById) {
 #ifdef KJS_VERBOSE
-        qDebug() << "DOMDocument::GetElementById looking for " << args[0]->toString(exec).qstring();
+        qCDebug(KHTML_LOG) << "DOMDocument::GetElementById looking for " << args[0]->toString(exec).qstring();
 #endif
         // create DOMStringImpl without copying
         DOMStringImpl shallowCopy(DOMStringImpl::ShallowCopy, (QChar *)str.data(), str.size());
@@ -1183,10 +1183,10 @@ JSValue *DOMDocumentProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj
             QString dstUrl = khtmlpart->htmlDocument().completeURL(s).string();
             KParts::ReadOnlyPart *part = static_cast<KJS::ScriptInterpreter *>(exec->dynamicInterpreter())->part();
             if (part->url().host() == QUrl(dstUrl).host()) {
-                // qDebug() << "JavaScript: access granted for document.load() of " << dstUrl;
+                // qCDebug(KHTML_LOG) << "JavaScript: access granted for document.load() of " << dstUrl;
                 doc.load(dstUrl);
             } else {
-                // qDebug() << "JavaScript: access denied for document.load() of " << dstUrl;
+                // qCDebug(KHTML_LOG) << "JavaScript: access denied for document.load() of " << dstUrl;
             }
         }
         break;
@@ -1251,7 +1251,7 @@ JSValue *DOMDocumentProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj
                                                     toNode(args[1]), // contextNode,
                                                     toResolver(exec, args[2]), // resolver
                                                     args[3]->toInt32(exec), // type
-                                                    0, // result reuse, ignored
+                                                    nullptr, // result reuse, ignored
                                                     exception));
     }
     default:
@@ -1295,7 +1295,7 @@ KJS_IMPLEMENT_PROTOTYPE("DOMElement", DOMElementProto, DOMElementProtoFunc, DOMN
 
 IMPLEMENT_PSEUDO_CONSTRUCTOR(ElementPseudoCtor, "Element", DOMElementProto)
 
-const ClassInfo DOMElement::info = { "Element", &DOMNode::info, &DOMElementTable, 0 };
+const ClassInfo DOMElement::info = { "Element", &DOMNode::info, &DOMElementTable, nullptr };
 /* Source for DOMElementTable.
 @begin DOMElementTable 7
   tagName       DOMElement::TagName                 DontDelete|ReadOnly
@@ -1337,7 +1337,7 @@ JSValue *DOMElement::getValueProperty(ExecState *exec, int token) const
     case ChildElementCount:
         return jsNumber((unsigned int)element.childElementCount());
     default:
-        // qDebug() << "WARNING: Unhandled token in DOMElement::getValueProperty : " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: Unhandled token in DOMElement::getValueProperty : " << token;
         return jsUndefined();
     }
 }
@@ -1345,7 +1345,7 @@ JSValue *DOMElement::getValueProperty(ExecState *exec, int token) const
 bool DOMElement::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMElement::getOwnPropertySlot " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMElement::getOwnPropertySlot " << propertyName.qstring();
 #endif
 
     //DOM::Element element = static_cast<DOM::Element>(node);
@@ -1486,7 +1486,7 @@ DOM::ElementImpl *KJS::toElement(JSValue *v)
     if (node && node->isElementNode()) {
         return static_cast<DOM::ElementImpl *>(node);
     }
-    return 0;
+    return nullptr;
 }
 
 DOM::AttrImpl *KJS::toAttr(JSValue *v)
@@ -1495,7 +1495,7 @@ DOM::AttrImpl *KJS::toAttr(JSValue *v)
     if (node && node->isAttributeNode()) {
         return static_cast<DOM::AttrImpl *>(node);
     }
-    return 0;
+    return nullptr;
 }
 
 // -------------------------------------------------------------------------
@@ -1514,7 +1514,7 @@ KJS_DEFINE_PROTOTYPE(DOMDOMImplementationProto)
 KJS_IMPLEMENT_PROTOFUNC(DOMDOMImplementationProtoFunc)
 KJS_IMPLEMENT_PROTOTYPE("DOMImplementation", DOMDOMImplementationProto, DOMDOMImplementationProtoFunc, ObjectPrototype)
 
-const ClassInfo DOMDOMImplementation::info = { "DOMImplementation", 0, 0, 0 };
+const ClassInfo DOMDOMImplementation::info = { "DOMImplementation", nullptr, nullptr, nullptr };
 
 DOMDOMImplementation::DOMDOMImplementation(ExecState *exec, DOM::DOMImplementationImpl *i)
     : DOMObject(DOMDOMImplementationProto::self(exec)), m_impl(i) { }
@@ -1580,7 +1580,7 @@ JSValue *DOMDOMImplementationProtoFunc::callAsFunction(ExecState *exec, JSObject
 
 // -------------------------------------------------------------------------
 
-const ClassInfo DOMDocumentType::info = { "DocumentType", &DOMNode::info, &DOMDocumentTypeTable, 0 };
+const ClassInfo DOMDocumentType::info = { "DocumentType", &DOMNode::info, &DOMDocumentTypeTable, nullptr };
 
 /* Source for DOMDocumentTypeTable.
 @begin DOMDocumentTypeTable 6
@@ -1599,7 +1599,7 @@ DOMDocumentType::DOMDocumentType(ExecState *exec, DOM::DocumentTypeImpl *dt)
 bool DOMDocumentType::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, KJS::PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMDocumentType::getOwnPropertySlot " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMDocumentType::getOwnPropertySlot " << propertyName.qstring();
 #endif
     return getStaticValueSlot<DOMDocumentType, DOMNode>(exec, &DOMDocumentTypeTable, this, propertyName, slot);
 }
@@ -1621,7 +1621,7 @@ JSValue *DOMDocumentType::getValueProperty(ExecState *exec, int token) const
     case InternalSubset: // DOM2
         return ::getStringOrNull(type.internalSubset()); // can be null, see domts/level2/core/internalSubset01.html
     default:
-        // qDebug() << "WARNING: DOMDocumentType::getValueProperty unhandled token " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: DOMDocumentType::getValueProperty unhandled token " << token;
         return jsNull();
     }
 }
@@ -1647,7 +1647,7 @@ KJS_DEFINE_PROTOTYPE(DOMNamedNodeMapProto)
 KJS_IMPLEMENT_PROTOFUNC(DOMNamedNodeMapProtoFunc)
 KJS_IMPLEMENT_PROTOTYPE("NamedNodeMap", DOMNamedNodeMapProto, DOMNamedNodeMapProtoFunc, ObjectPrototype)
 
-const ClassInfo DOMNamedNodeMap::info = { "NamedNodeMap", 0, &DOMNamedNodeMapTable, 0 };
+const ClassInfo DOMNamedNodeMap::info = { "NamedNodeMap", nullptr, &DOMNamedNodeMapTable, nullptr };
 
 DOMNamedNodeMap::DOMNamedNodeMap(ExecState *exec, DOM::NamedNodeMapImpl *m)
     : DOMObject(DOMNamedNodeMapProto::self(exec)), m_impl(m) { }
@@ -1729,7 +1729,7 @@ JSValue *DOMNamedNodeMapProtoFunc::callAsFunction(ExecState *exec, JSObject *thi
 
 // -------------------------------------------------------------------------
 //### FIXME: proto
-const ClassInfo DOMProcessingInstruction::info = { "ProcessingInstruction", &DOMNode::info, &DOMProcessingInstructionTable, 0 };
+const ClassInfo DOMProcessingInstruction::info = { "ProcessingInstruction", &DOMNode::info, &DOMProcessingInstructionTable, nullptr };
 
 /* Source for DOMProcessingInstructionTable.
 @begin DOMProcessingInstructionTable 3
@@ -1754,7 +1754,7 @@ JSValue *DOMProcessingInstruction::getValueProperty(ExecState *exec, int token)
     case Sheet:
         return getDOMStyleSheet(exec, pi.sheet());
     default:
-        // qDebug() << "WARNING: DOMProcessingInstruction::getValueProperty unhandled token " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: DOMProcessingInstruction::getValueProperty unhandled token " << token;
         return jsNull();
     }
 }
@@ -1773,7 +1773,7 @@ void DOMProcessingInstruction::put(ExecState *exec, const Identifier &propertyNa
 
 // -------------------------------------------------------------------------
 
-const ClassInfo DOMNotation::info = { "Notation", &DOMNode::info, &DOMNotationTable, 0 };
+const ClassInfo DOMNotation::info = { "Notation", &DOMNode::info, &DOMNotationTable, nullptr };
 
 /* Source for DOMNotationTable.
 @begin DOMNotationTable 2
@@ -1795,14 +1795,14 @@ JSValue *DOMNotation::getValueProperty(ExecState *, int token) const
     case SystemId:
         return jsString(nota.systemId());
     default:
-        // qDebug() << "WARNING: DOMNotation::getValueProperty unhandled token " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: DOMNotation::getValueProperty unhandled token " << token;
         return jsNull();
     }
 }
 
 // -------------------------------------------------------------------------
 
-const ClassInfo DOMEntity::info = { "Entity", &DOMNode::info, 0, 0 };
+const ClassInfo DOMEntity::info = { "Entity", &DOMNode::info, nullptr, nullptr };
 
 /* Source for DOMEntityTable.
 @begin DOMEntityTable 2
@@ -1827,7 +1827,7 @@ JSValue *DOMEntity::getValueProperty(ExecState *, int token) const
     case NotationName:
         return jsString(entity.notationName());
     default:
-        // qDebug() << "WARNING: DOMEntity::getValueProperty unhandled token " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: DOMEntity::getValueProperty unhandled token " << token;
         return jsNull();
     }
 }
@@ -1841,7 +1841,7 @@ bool KJS::checkNodeSecurity(ExecState *exec, const DOM::NodeImpl *n)
         return true;
     }
     KHTMLPart *part = n->document()->part();
-    Window *win = part ? Window::retrieveWindow(part) : 0L;
+    Window *win = part ? Window::retrieveWindow(part) : nullptr;
     if (!win || !win->isSafeScript(exec)) {
         return false;
     }
@@ -1875,7 +1875,7 @@ JSValue *KJS::getEventTarget(ExecState *exec, DOM::EventTargetImpl *t)
 
 JSValue *KJS::getDOMNode(ExecState *exec, DOM::NodeImpl *n)
 {
-    DOMObject *ret = 0;
+    DOMObject *ret = nullptr;
     if (!n) {
         return jsNull();
     }
@@ -2008,7 +2008,7 @@ JSDOMException::JSDOMException(ExecState *exec)
 {
 }
 
-const ClassInfo JSDOMException::info = { "DOMException", 0, 0, 0 };
+const ClassInfo JSDOMException::info = { "DOMException", nullptr, nullptr, nullptr };
 
 JSObject *KJS::getDOMExceptionConstructor(ExecState *exec)
 {
@@ -2022,7 +2022,7 @@ JSObject *KJS::getDOMExceptionConstructor(ExecState *exec)
   length        KJS::DOMNamedNodesCollection::Length        DontDelete|ReadOnly
 @end
 */
-const ClassInfo KJS::DOMNamedNodesCollection::info = { "DOMNamedNodesCollection", 0, &DOMNamedNodesCollectionTable, 0 };
+const ClassInfo KJS::DOMNamedNodesCollection::info = { "DOMNamedNodesCollection", nullptr, &DOMNamedNodesCollectionTable, nullptr };
 
 // Such a collection is usually very short-lived, it only exists
 // for constructs like document.forms.<name>[1],
@@ -2047,7 +2047,7 @@ JSValue *DOMNamedNodesCollection::lengthGetter(ExecState *, JSObject *, const Id
 
 bool DOMNamedNodesCollection::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
-    // qDebug() << propertyName.ascii();
+    // qCDebug(KHTML_LOG) << propertyName.ascii();
 
     if (propertyName == exec->propertyNames().length) {
         slot.setCustom(this, lengthGetter);
@@ -2065,7 +2065,7 @@ bool DOMNamedNodesCollection::getOwnPropertySlot(ExecState *exec, const Identifi
 // -------------------------------------------------------------------------
 
 const ClassInfo DOMCharacterData::info = { "CharacterImp",
-                                           &DOMNode::info, &DOMCharacterDataTable, 0
+                                           &DOMNode::info, &DOMCharacterDataTable, nullptr
                                          };
 /*
 @begin DOMCharacterDataTable 2
@@ -2093,7 +2093,7 @@ DOMCharacterData::DOMCharacterData(ExecState *exec, DOM::CharacterDataImpl *d)
 bool DOMCharacterData::getOwnPropertySlot(ExecState *exec, const Identifier &propertyName, PropertySlot &slot)
 {
 #ifdef KJS_VERBOSE
-    qDebug() << "DOMCharacterData::tryGet " << propertyName.qstring();
+    qCDebug(KHTML_LOG) << "DOMCharacterData::tryGet " << propertyName.qstring();
 #endif
     return getStaticValueSlot<DOMCharacterData, DOMNode>(exec, &DOMCharacterDataTable, this, propertyName, slot);
 }
@@ -2107,7 +2107,7 @@ JSValue *DOMCharacterData::getValueProperty(ExecState *, int token) const
     case Length:
         return jsNumber(data.length());
     default:
-        // qDebug() << "WARNING: Unhandled token in DOMCharacterData::getValueProperty : " << token;
+        // qCDebug(KHTML_LOG) << "WARNING: Unhandled token in DOMCharacterData::getValueProperty : " << token;
         return jsNull();
     }
 }
@@ -2154,7 +2154,7 @@ JSValue *DOMCharacterDataProtoFunc::callAsFunction(ExecState *exec, JSObject *th
 // -------------------------------------------------------------------------
 
 const ClassInfo DOMText::info = { "Text", &DOMCharacterData::info,
-                                  &DOMTextTable, 0
+                                  &DOMTextTable, nullptr
                                 };
 
 /*
@@ -2212,7 +2212,7 @@ JSValue *DOMTextProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj, co
 // -------------------------------------------------------------------------
 
 const ClassInfo DOMComment::info = { "Comment",
-                                     &DOMCharacterData::info, 0, 0
+                                     &DOMCharacterData::info, nullptr, nullptr
                                    };
 /*
 @begin DOMCommentProtoTable 1
@@ -2238,7 +2238,7 @@ JSValue *DOMCommentProtoFunc::callAsFunction(ExecState *exec, JSObject *thisObj,
 // -------------------------------------------------------------------------
 
 const ClassInfo DOMDocumentFragment::info = { "DocumentFragment",
-                                              &DOMNode::info, 0, 0
+                                              &DOMNode::info, nullptr, nullptr
                                             };
 /*
 @begin DOMDocumentFragmentProtoTable 2
