@@ -48,7 +48,7 @@ static bool isForeignObject(const QVariant &v)
 
 QVariant exception(const char *msg)
 {
-    qWarning() << msg;
+    qCWarning(KHTML_LOG) << msg;
     return QVariant::fromValue(ScriptableExtension::Exception(QString::fromLatin1(msg)));
 }
 
@@ -84,12 +84,12 @@ bool pluginRootGet(ExecState *exec, ScriptableExtension *ext, const KJS::Identif
         return false;
     }
 
-    QVariant v = rootObj.owner->get(0 /* ### we don't expect leaves to check credentials*/,
+    QVariant v = rootObj.owner->get(nullptr /* ### we don't expect leaves to check credentials*/,
                                     rootObj.objId, i.qstring());
 
     bool ok = false;
     if (!isException(v)) {
-        getImmediateValueSlot(0, ScriptableOperations::importValue(exec, v, true), slot);
+        getImmediateValueSlot(nullptr, ScriptableOperations::importValue(exec, v, true), slot);
         ok = true;
     }
 
@@ -105,7 +105,7 @@ bool pluginRootPut(ExecState * /*exec*/, ScriptableExtension *ext, const KJS::Id
     }
 
     QVariant qv = ScriptableOperations::exportValue(v, true);
-    bool ok = rootObj.owner->put(0, rootObj.objId, i.qstring(), qv);
+    bool ok = rootObj.owner->put(nullptr, rootObj.objId, i.qstring(), qv);
     ScriptableExtension::releaseValue(qv);
 
     rootObj.owner->release(rootObj.objId);
@@ -115,7 +115,7 @@ bool pluginRootPut(ExecState * /*exec*/, ScriptableExtension *ext, const KJS::Id
 //------------------------------------------------------------------------------
 // KJS peer wrapping external objects
 
-const ClassInfo WrapScriptableObject::info = { " WrapScriptableObject", 0, 0, 0 };
+const ClassInfo WrapScriptableObject::info = { " WrapScriptableObject", nullptr, nullptr, nullptr };
 
 WrapScriptableObject::WrapScriptableObject(ExecState * /*exec*/, Type t,
         ScriptableExtension *owner, quint64 objId,
@@ -341,7 +341,7 @@ ScriptableExtension *WrapScriptableObject::principal(ExecState *exec)
     KJS::ScriptInterpreter *si = static_cast<KJS::ScriptInterpreter *>(exec->dynamicInterpreter());
     KParts::ReadOnlyPart   *part = si->part();
     if (!part) {
-        return 0;
+        return nullptr;
     }
 
     return ScriptableExtension::childObject(part);
@@ -427,7 +427,7 @@ JSValue *ScriptableOperations::importValue(ExecState *exec, const QVariant &v, b
     if (v.canConvert<double>()) {
         return jsNumber(v.toDouble());
     }
-    qWarning() << "conversion from " << v << "failed";
+    qCWarning(KHTML_LOG) << "conversion from " << v << "failed";
     return jsNull();
 }
 
@@ -471,7 +471,7 @@ QVariant ScriptableOperations::exportObject(JSObject *o, bool preRef)
             }
             return v;
         } else {
-            qWarning() << "export of an object of a destroyed extension. Returning null";
+            qCWarning(KHTML_LOG) << "export of an object of a destroyed extension. Returning null";
             return scriptableNull();
         }
     } else {
@@ -506,10 +506,10 @@ QVariant ScriptableOperations::exportValue(JSValue *v, bool preRef)
 
 //-----------------------------------------------------------------------------
 // operations
-QHash<JSObject *, int> *ScriptableOperations::s_exportedObjects = 0;
-QHash<ScriptableExtension::Object, WrapScriptableObject *> *ScriptableOperations::s_importedObjects   = 0;
-QHash<ScriptableExtension::FunctionRef, WrapScriptableObject *> *ScriptableOperations::s_importedFunctions = 0;
-ScriptableOperations *ScriptableOperations::s_instance = 0;
+QHash<JSObject *, int> *ScriptableOperations::s_exportedObjects = nullptr;
+QHash<ScriptableExtension::Object, WrapScriptableObject *> *ScriptableOperations::s_importedObjects   = nullptr;
+QHash<ScriptableExtension::FunctionRef, WrapScriptableObject *> *ScriptableOperations::s_importedFunctions = nullptr;
+ScriptableOperations *ScriptableOperations::s_instance = nullptr;
 
 QHash<ScriptableExtension::Object, WrapScriptableObject *> *ScriptableOperations::importedObjects()
 {
@@ -532,7 +532,7 @@ QHash<ScriptableExtension::FunctionRef, WrapScriptableObject *> *ScriptableOpera
 class ScriptableOperationsMarker: public JSObject
 {
 public:
-    void mark() Q_DECL_OVERRIDE
+    void mark() override
     {
         JSObject::mark();
         ScriptableOperations::self()->mark();
@@ -557,7 +557,7 @@ ScriptableOperations *ScriptableOperations::self()
     return s_instance;
 }
 
-ScriptableOperations::ScriptableOperations(): ScriptableExtension(0)
+ScriptableOperations::ScriptableOperations(): ScriptableExtension(nullptr)
 {}
 
 ScriptableOperations::~ScriptableOperations()
@@ -570,7 +570,7 @@ JSObject *ScriptableOperations::tryGetNativeObject(const Object &sObj)
     if (ScriptableOperations *o = qobject_cast<ScriptableOperations *>(sObj.owner)) {
         return o->objectForId(sObj.objId);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -780,17 +780,17 @@ ExecState *ScriptableOperations::execStateForPrincipal(ScriptableExtension *call
     KHTMLPart *part = partForPrincipal(caller);
 
     if (!part) {
-        return 0;
+        return nullptr;
     }
 
     KJSProxy *proxy = KJSProxy::proxy(part);
     if (!proxy) {
-        return 0;
+        return nullptr;
     }
 
     KJS::Interpreter *i = proxy->interpreter();
     if (!i) {
-        return 0;
+        return nullptr;
     }
 
     return i->globalExec();
@@ -830,7 +830,7 @@ JSObject *ScriptableOperations::objectForId(quint64 objId)
         return ptr;
     } else {
         assert(false);
-        return 0;
+        return nullptr;
     }
 }
 
@@ -858,7 +858,7 @@ KJS::Interpreter *KHTMLPartScriptable::interpreter()
 {
     KJSProxy *proxy = KJSProxy::proxy(m_part);
     if (!proxy) {
-        return 0;
+        return nullptr;
     }
 
     return proxy->interpreter();
@@ -885,7 +885,7 @@ QVariant KHTMLPartScriptable::encloserForKid(KParts::ScriptableExtension *kid)
     khtml::ChildFrame *f = m_part->frame(childPart);
 
     if (!f) {
-        qWarning() << "unable to find frame. Huh?";
+        qCWarning(KHTML_LOG) << "unable to find frame. Huh?";
         return scriptableNull();
     }
 
@@ -896,7 +896,7 @@ QVariant KHTMLPartScriptable::encloserForKid(KParts::ScriptableExtension *kid)
                    getDOMNode(i->globalExec(), f->m_partContainerElement.data()), true);
     }
 
-    qWarning() << "could not find the part container";
+    qCWarning(KHTML_LOG) << "could not find the part container";
     return scriptableNull();
 }
 
@@ -916,7 +916,7 @@ QVariant KHTMLPartScriptable::evaluateScript(ScriptableExtension *caller,
         const QString &code,
         ScriptLanguage lang)
 {
-    // qDebug() << code;
+    // qCDebug(KHTML_LOG) << code;
 
     if (lang != ECMAScript) {
         return exception("unsupported language");
@@ -968,7 +968,7 @@ bool KHTMLPartScriptable::isScriptLanguageSupported(ScriptLanguage lang) const
 bool KHTMLPartScriptable::setException(ScriptableExtension * /*caller*/,
                                        const QString &message)
 {
-    qWarning() << "ignoring:" << message;
+    qCWarning(KHTML_LOG) << "ignoring:" << message;
     return false;
 }
 
